# Plotly backend

```{eval-rst}
.. currentmodule:: plopp

.. autosummary::
   :toctree: ../generated

   backends.plotly.PlotlyBackend
   backends.plotly.canvas.Canvas
   backends.plotly.line.Line
   backends.plotly.figure.Figure
```
